Changes
=======

0.5.2
-----

* Fix incorrect ``psy status``.
* Fix ``psy run <task1> <task2> ...`` not running all tasks and run them in
  order.

0.5.1
-----

Bug fixes
^^^^^^^^^

* Fix ``psy merge`` always assuming ``PickleStore``.

Documentation improvements
^^^^^^^^^^^^^^^^^^^^^^^^^^

* Add recipe for converting data to Pandas data frame to documentation.


0.5
---

* Initial release
